@@ -77,7 +77,7 @@ class GameBotClient:
         config = Ini(user_config) if user_config.exists() else Ini(default_config)
         self.server_id = server_id
         self.host = host or config['NETWORK']['host'] or '127.0.0.1'
-        self.port = host or int(config['NETWORK']['port']) or 65432
+        self.port = int(port) or int(config['NETWORK']['port']) or 65432
         self.server_address = f"{self.host}:{self.port}"
         self.client_address = None
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
